This is unreleased documentation for the main (development) branch of crypto-glue.

Criticality

Trait Criticality 

pub trait Criticality {
    // Required method
    fn criticality(&self, subject: &Name, extensions: &[Extension]) -> bool;
}
Trait for types that define their default criticality as an extension.

This is used for most der::Encode types that are used as extensions.

Required Methods

fn criticality(&self, subject: &Name, extensions: &[Extension]) -> bool

Should the extension be marked critical

This affects the behavior of a validator when using the generated certificate. See RFC 5280 Section 4.2:

A certificate-using system MUST reject the certificate if it encounters
a critical extension it does not recognize or a critical extension
that contains information that it cannot process.  A non-critical
extension MAY be ignored if it is not recognized, but MUST be
processed if it is recognized.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors